@@ -11,7 +11,8 @@ sys.path.insert(1, ".")
 
 from mldock.__version__ import __version__
 from mldock.__init__ import MLDOCK_LOGO
-from mldock.command.initialize import init
+# from mldock.command.initialize import init
+from mldock.command.container import container
 from mldock.command.local import local
 from mldock.command.cloud import cloud
 from mldock.log import configure_logger
@@ -35,7 +36,7 @@ def cli(ctx, verbose, docker_tag):
     ctx.obj = {'verbose': verbose, 'docker_tag': docker_tag, 'helper_library_path':_FILE_DIR_PATH}
 
 def add_commands(cli):
-    cli.add_command(init)
+    cli.add_command(container)
     cli.add_command(local)
     cli.add_command(cloud)
 
